@@ -6,6 +6,7 @@ from typing import Type, List, cast, Optional
 
 import icu as icu
 from pydantic import BaseModel, Field
+from pymultirole_plugins.util import comma_separated_to_list
 from pymultirole_plugins.v1.annotator import AnnotatorParameters, AnnotatorBase
 from pymultirole_plugins.v1.schema import Document, Category, Sentence
 from transformers import pipeline, ZeroShotClassificationPipeline
@@ -40,9 +41,9 @@ class ZeroShotClassifierParameters(AnnotatorParameters):
                                             documents, can be one of:<br/>
                                             <li>`document`
                                             <li>`segment`""")
-    candidate_labels: List[str] = Field([],
-                                        description="The set of possible class labels to classify each sequence into. "
-                                                    "For example `[\"sport\",\"politics\",\"science\"]`")
+    candidate_labels: str = Field("sport,politics,science",
+                                  description="""The comma-separated list of possible class labels to classify
+                                        each sequence into. For example `\"sport,politics,science\"`""")
     multi_label: bool = Field(False, description="Whether or not multiple candidate labels can be true.")
     multi_label_threshold: float = Field(0.5,
                                          description="If multi-label you can set the threshold to make predictions.")
@@ -71,7 +72,7 @@ class ZeroShotClassifierAnnotator(AnnotatorBase):
                 params.hypothesis_template = "Ce texte parle de {}."
         # Create cached pipeline context with model
         p: ZeroShotClassificationPipeline = get_pipeline(params.model)
-
+        candidate_labels = comma_separated_to_list(params.candidate_labels)
         for document in documents:
             if params.processing_unit == ProcessingUnit.document:
                 result = p(document.text, params.candidate_labels, hypothesis_template=params.hypothesis_template)
@@ -80,7 +81,7 @@ class ZeroShotClassifierAnnotator(AnnotatorBase):
                 if not document.sentences:
                     document.sentences = [Sentence(start=0, end=len(document.text))]
                 stexts = [document.text[s.start:s.end] for s in document.sentences]
-                results = p(stexts, params.candidate_labels, hypothesis_template=params.hypothesis_template)
+                results = p(stexts, candidate_labels, hypothesis_template=params.hypothesis_template)
                 for sent, result in zip(document.sentences, results):
                     sent.categories = compute_categories(result, params.multi_label_threshold, params.multi_label)
         return documents
