@@ -30,7 +30,7 @@ def test_zeroshotclassifier_english(expected_en):
     assert model_class == ZeroShotClassifierParameters
     annotator = ZeroShotClassifierAnnotator()
     parameters = ZeroShotClassifierParameters(model=TrfModel.distilbert_base_uncased_mnli,
-                                              candidate_labels=list(expected_en.keys()),
+                                              candidate_labels=','.join(expected_en.keys()),
                                               multi_label=True)
     docs: List[Document] = annotator.annotate([Document(text=t) for t in expected_en.values()], parameters)
     for expected_label, doc in zip(expected_en.keys(), docs):
@@ -53,7 +53,7 @@ def test_zeroshotclassifier_english_segments(expected_en):
         doc.text.rstrip()
         doc.sentences[-1].end -= 1
     parameters = ZeroShotClassifierParameters(model=TrfModel.distilbert_base_uncased_mnli,
-                                              candidate_labels=list(expected_en.keys()),
+                                              candidate_labels=','.join(expected_en.keys()),
                                               processing_unit=ProcessingUnit.segment,
                                               multi_label=True)
     docs: List[Document] = annotator.annotate([doc], parameters)
@@ -67,7 +67,7 @@ def test_zeroshotclassifier_french(expected_fr):
     assert model_class == ZeroShotClassifierParameters
     annotator = ZeroShotClassifierAnnotator()
     parameters = ZeroShotClassifierParameters(model=TrfModel.camembert_base_xnli,
-                                              candidate_labels=list(expected_fr.keys()),
+                                              candidate_labels=','.join(expected_fr.keys()),
                                               multi_label=True)
     docs: List[Document] = annotator.annotate([Document(text=t) for t in expected_fr.values()], parameters)
     for expected_label, doc in zip(expected_fr.keys(), docs):
@@ -90,7 +90,7 @@ def test_zeroshotclassifier_french_segments(expected_fr):
         doc.text.rstrip()
         doc.sentences[-1].end -= 1
     parameters = ZeroShotClassifierParameters(model=TrfModel.camembert_base_xnli,
-                                              candidate_labels=list(expected_fr.keys()),
+                                              candidate_labels=','.join(expected_fr.keys()),
                                               processing_unit=ProcessingUnit.segment,
                                               multi_label=True)
     docs: List[Document] = annotator.annotate([doc], parameters)
